﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Telerik.Windows.Media.Imaging.ImageEditorCommands;
using Microsoft.Win32;
using System.IO;
using Telerik.Windows.Media.Imaging.FormatProviders;
using System.Windows;
using Telerik.Windows.Controls;

namespace ImageEditor
{
    class CustomOpenCommand : OpenImageCommand
    {
        public CustomOpenCommand(Telerik.Windows.Controls.RadImageEditor owner)
            : base(owner)
        {
        }

        protected override void ExecuteOverride(object parameter)
        {
            OpenFileDialog dialog = new OpenFileDialog();

            dialog.Filter = "JPEG Images (*.jpg,*.jpeg)|*.jpg;*.jpeg";

            if (dialog.ShowDialog() == true)
            {
                string extension;
                extension = Path.GetExtension(dialog.SafeFileName).ToLower();

                try
                {
                    Stream stream = dialog.OpenFile();

                    IImageFormatProvider formatProvider = ImageFormatProviderManager.GetFormatProviderByExtension(extension);

                    if (formatProvider == null)
                    {
                        StringBuilder sb = new StringBuilder();
                        sb.Append("Unable to find format provider for extension: ")
                            .Append(extension).Append(" .");

                        CommandErrorEventArgs args = new CommandErrorEventArgs(new InvalidOperationException(sb.ToString()));

                        if (!args.Handled)
                        {
                            MessageBox.Show(LocalizationManager.GetString("ImageEditor_UnsupportedFileFormat"));
                        }

                        return;
                    }

                    this.Owner.Image = formatProvider.Import(stream);
                }
                catch (IOException ex)
                {
                    CommandErrorEventArgs args = new CommandErrorEventArgs(ex);
                    if (!args.Handled)
                    {
                        MessageBox.Show(LocalizationManager.GetString("ImageEditor_TheFileIsLocked"));
                    }
                }
                catch (Exception ex)
                {
                    CommandErrorEventArgs args = new CommandErrorEventArgs(ex);
                    if (!args.Handled)
                    {
                        MessageBox.Show(LocalizationManager.GetString("ImageEditor_TheFileCannotBeOpened"));
                    }
                }
            }
        }
    }
}
